---
title: <span class="badge object-type-scalar"></span> Litre
---
# <span class="badge object-type-scalar"></span> Litre

Volume: litre (L)

## Definition

```python
# Volume: litre (L)
Litre: typing.Literal["litre"] = "litre"
```
